@@ -63,9 +63,10 @@ where
     ))
 }
 
-#[derive(Clone, Copy, PartialEq, Eq, Debug)]
+#[derive(Clone, Copy, PartialEq, Eq, Debug, Default)]
 #[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 pub enum QuantileInterpolOptions {
+    #[default]
     Nearest,
     Lower,
     Higher,
@@ -73,12 +74,6 @@ pub enum QuantileInterpolOptions {
     Linear,
 }
 
-impl Default for QuantileInterpolOptions {
-    fn default() -> Self {
-        QuantileInterpolOptions::Nearest
-    }
-}
-
 pub(super) fn rolling_apply_weights<T, Fo, Fa>(
     values: &[T],
     window_size: usize,
