@@ -6,9 +6,11 @@ pub mod conversion;
 pub mod data_types;
 pub mod error;
 pub mod export;
+pub mod floats;
 pub mod index;
 pub mod is_valid;
 pub mod kernels;
 pub mod prelude;
+pub mod slice;
 pub mod trusted_len;
 pub mod utils;
