@@ -8,6 +8,7 @@ use std::cmp::Ordering;
 use std::hint::unreachable_unchecked;
 use std::iter::FromIterator;
 
+pub(crate) use arg_sort_multiple::argsort_multiple_row_fmt;
 use arrow::bitmap::MutableBitmap;
 use arrow::buffer::Buffer;
 use num::Float;
@@ -23,6 +24,7 @@ use crate::prelude::sort::arg_sort_multiple::{arg_sort_multiple_impl, args_valid
 use crate::prelude::*;
 use crate::series::IsSorted;
 use crate::utils::{CustomIterTools, NoNull};
+use crate::POOL;
 
 /// Reverse sorting when there are no nulls
 fn order_descending<T: Ord>(a: &T, b: &T) -> Ordering {
@@ -58,14 +60,14 @@ fn sort_branch<T, Fd, Fr>(
     parallel: bool,
 ) where
     T: PartialOrd + Send,
-    Fd: FnMut(&T, &T) -> Ordering + for<'r, 's> Fn(&'r T, &'s T) -> Ordering + Sync,
-    Fr: FnMut(&T, &T) -> Ordering + for<'r, 's> Fn(&'r T, &'s T) -> Ordering + Sync,
+    Fd: FnMut(&T, &T) -> Ordering + for<'r, 's> Fn(&'r T, &'s T) -> Ordering + Sync + Send,
+    Fr: FnMut(&T, &T) -> Ordering + for<'r, 's> Fn(&'r T, &'s T) -> Ordering + Sync + Send,
 {
     if parallel {
-        match descending {
+        POOL.install(|| match descending {
             true => slice.par_sort_unstable_by(descending_order_fn),
             false => slice.par_sort_unstable_by(ascending_order_fn),
-        }
+        })
     } else {
         match descending {
             true => slice.sort_unstable_by(descending_order_fn),
@@ -97,14 +99,14 @@ pub fn arg_sort_branch<T, Fd, Fr>(
     parallel: bool,
 ) where
     T: PartialOrd + Send,
-    Fd: FnMut(&T, &T) -> Ordering + for<'r, 's> Fn(&'r T, &'s T) -> Ordering + Sync,
-    Fr: FnMut(&T, &T) -> Ordering + for<'r, 's> Fn(&'r T, &'s T) -> Ordering + Sync,
+    Fd: FnMut(&T, &T) -> Ordering + for<'r, 's> Fn(&'r T, &'s T) -> Ordering + Sync + Send,
+    Fr: FnMut(&T, &T) -> Ordering + for<'r, 's> Fn(&'r T, &'s T) -> Ordering + Sync + Send,
 {
     if parallel {
-        match descending {
+        POOL.install(|| match descending {
             true => slice.par_sort_by(descending_order_fn),
             false => slice.par_sort_by(ascending_order_fn),
-        }
+        })
     } else {
         match descending {
             true => slice.sort_by(descending_order_fn),
@@ -727,6 +729,30 @@ impl ChunkSort<BooleanType> for BooleanChunked {
     }
 }
 
+#[cfg(feature = "sort_multiple")]
+pub(crate) fn convert_sort_column_multi_sort(s: &Series) -> PolarsResult<Series> {
+    use DataType::*;
+    let out = match s.dtype() {
+        #[cfg(feature = "dtype-categorical")]
+        Categorical(_) => s.rechunk(),
+        #[cfg(feature = "dtype-binary")]
+        Binary => s.clone(),
+        Utf8 => s.clone(),
+        // TODO! remove this. With row ordering we can do this easily
+        Boolean => s.cast(&UInt8).unwrap(),
+        _ => {
+            let phys = s.to_physical_repr().into_owned();
+            if !phys.dtype().is_numeric() {
+                return Err(PolarsError::ComputeError(
+                    format!("Cannot sort column of dtype: {:?}", s.dtype()).into(),
+                ));
+            }
+            phys
+        }
+    };
+    Ok(out)
+}
+
 #[cfg(feature = "sort_multiple")]
 pub(crate) fn prepare_arg_sort(
     columns: Vec<Series>,
@@ -736,24 +762,8 @@ pub(crate) fn prepare_arg_sort(
 
     let mut columns = columns
         .iter()
-        .map(|s| {
-            use DataType::*;
-            match s.dtype() {
-                Float32 | Float64 | Int32 | Int64 | Utf8 | UInt32 | UInt64 => s.clone(),
-                #[cfg(feature = "dtype-categorical")]
-                Categorical(_) => s.rechunk(),
-                _ => {
-                    // small integers i8, u8 etc are casted to reduce compiler bloat
-                    // not that we don't expect any logical types at this point
-                    if s.bit_repr_is_large() {
-                        s.cast(&DataType::Int64).unwrap()
-                    } else {
-                        s.cast(&DataType::Int32).unwrap()
-                    }
-                }
-            }
-        })
-        .collect::<Vec<_>>();
+        .map(convert_sort_column_multi_sort)
+        .collect::<PolarsResult<Vec<_>>>()?;
 
     let first = columns.remove(0);
 
