@@ -228,6 +228,10 @@ impl Series {
 
     /// Cast `[Series]` to another `[DataType]`
     pub fn cast(&self, dtype: &DataType) -> PolarsResult<Self> {
+        // best leave as is.
+        if matches!(dtype, DataType::Unknown) {
+            return Ok(self.clone());
+        }
         match self.0.cast(dtype) {
             Ok(out) => Ok(out),
             Err(err) => {
@@ -687,7 +691,7 @@ impl Series {
             use DataType::*;
             match self.dtype() {
                 Boolean => self.cast(&DataType::Int64).unwrap().product(),
-                Int8 | UInt8 | Int16 | UInt16 => {
+                Int8 | UInt8 | Int16 | UInt16 | Int32 | UInt32 => {
                     let s = self.cast(&Int64).unwrap();
                     s.product()
                 }
@@ -695,6 +699,10 @@ impl Series {
                     let ca = self.i64().unwrap();
                     ca.prod_as_series()
                 }
+                UInt64 => {
+                    let ca = self.u64().unwrap();
+                    ca.prod_as_series()
+                }
                 Float32 => {
                     let ca = self.f32().unwrap();
                     ca.prod_as_series()
