@@ -237,6 +237,22 @@ fn test_csv_globbing() -> PolarsResult<()> {
     Ok(())
 }
 
+#[test]
+#[cfg(not(target_os = "windows"))]
+#[cfg(feature = "json")]
+fn test_ndjson_globbing() -> PolarsResult<()> {
+    // for side effects
+    init_files();
+    let glob = "../../examples/datasets/*.ndjson";
+    let df = LazyJsonLineReader::new(glob.into()).finish()?.collect()?;
+    assert_eq!(df.shape(), (54, 4));
+    let cal = df.column("calories")?;
+    assert_eq!(cal.get(0)?, AnyValue::Int64(45));
+    assert_eq!(cal.get(53)?, AnyValue::Int64(194));
+
+    Ok(())
+}
+
 #[test]
 pub fn test_simple_slice() -> PolarsResult<()> {
     let _guard = SINGLE_LOCK.lock().unwrap();
