@@ -7,11 +7,12 @@ use base64::Engine as _;
 use polars_arrow::export::arrow::compute::substring::substring;
 use polars_arrow::export::arrow::{self};
 use polars_arrow::kernels::string::*;
+#[cfg(feature = "string_from_radix")]
 use polars_core::export::num::Num;
 use polars_core::export::regex::{escape, NoExpand, Regex};
 
 use super::*;
-#[cfg(feature = "string_encoding")]
+#[cfg(feature = "binary_encoding")]
 use crate::chunked_array::binary::BinaryNameSpaceImpl;
 
 fn f_regex_extract<'a>(reg: &Regex, input: &'a str, group_index: usize) -> Option<Cow<'a, str>> {
@@ -160,14 +161,22 @@ pub trait Utf8NameSpaceImpl: AsUtf8 {
     }
 
     /// Check if strings contain a regex pattern.
-    fn contains(&self, pat: &str) -> PolarsResult<BooleanChunked> {
+    fn contains(&self, pat: &str, strict: bool) -> PolarsResult<BooleanChunked> {
         let ca = self.as_utf8();
-        let reg = Regex::new(pat)?;
-        let f = |s: &str| reg.is_match(s);
-        let mut out: BooleanChunked = if !ca.has_validity() {
-            ca.into_no_null_iter().map(f).collect()
-        } else {
-            ca.into_iter().map(|opt_s| opt_s.map(f)).collect()
+
+        let res_reg = Regex::new(pat);
+        let opt_reg = if strict { Some(res_reg?) } else { res_reg.ok() };
+
+        let mut out: BooleanChunked = match (opt_reg, ca.has_validity()) {
+            (Some(reg), false) => ca
+                .into_no_null_iter()
+                .map(|s: &str| reg.is_match(s))
+                .collect(),
+            (Some(reg), true) => ca
+                .into_iter()
+                .map(|opt_s| opt_s.map(|s: &str| reg.is_match(s)))
+                .collect(),
+            (None, _) => ca.into_iter().map(|_| None).collect(),
         };
         out.rename(ca.name());
         Ok(out)
@@ -178,7 +187,7 @@ pub trait Utf8NameSpaceImpl: AsUtf8 {
         // note: benchmarking shows that the regex engine is actually
         // faster at finding literal matches than str::contains.
         // ref: https://github.com/pola-rs/polars/pull/6811
-        self.contains(escape(lit).as_str())
+        self.contains(escape(lit).as_str(), true)
     }
 
     /// Check if strings ends with a substring
