@@ -25,10 +25,7 @@ pub fn date_range_impl(
 
     #[cfg(feature = "timezones")]
     if let Some(tz) = _tz {
-        out = out
-            .with_time_zone(Some("UTC".to_string()))?
-            .cast_time_zone(Some(tz))
-            .unwrap()
+        out = out.replace_time_zone(Some(tz))?
     }
     let s = if start > stop {
         IsSorted::Descending
