@@ -16,6 +16,7 @@ from polars.build_info import build_info
 from polars.cfg import Config
 from polars.convert import (
     from_arrow,
+    from_dataframe,
     from_dict,
     from_dicts,
     from_numpy,
@@ -53,20 +54,24 @@ from polars.datatypes import (
 )
 from polars.exceptions import (
     ArrowError,
+    ColumnNotFoundError,
     ComputeError,
     DuplicateError,
     InvalidOperationError,
     NoDataError,
-    NotFoundError,
     PanicException,
     SchemaError,
+    SchemaFieldNotFoundError,
     ShapeError,
+    StructFieldNotFoundError,
 )
 from polars.internals import BatchedCsvReader
 
 # TODO remove need for wrap_df
-from polars.internals.dataframe import wrap_df  # noqa: F401
-from polars.internals.dataframe import DataFrame
+from polars.internals.dataframe import (
+    DataFrame,
+    wrap_df,  # noqa: F401
+)
 from polars.internals.expr.expr import Expr
 from polars.internals.functions import (
     align_frames,
@@ -85,6 +90,7 @@ from polars.internals.lazy_functions import (
     any,
     apply,
     arange,
+    arg_sort_by,
     arg_where,
     argsort_by,
     avg,
@@ -125,9 +131,9 @@ from polars.internals.lazy_functions import (
     struct,
     sum,
     tail,
+    var,
 )
 from polars.internals.lazy_functions import to_list as list
-from polars.internals.lazy_functions import var
 from polars.internals.lazyframe import LazyFrame
 
 # TODO: remove need for wrap_s
@@ -160,66 +166,71 @@ from polars.utils import threadpool_size
 __all__ = [
     "api",
     "exceptions",
-    "NotFoundError",
-    "ShapeError",
-    "SchemaError",
+    # exceptions/errors
     "ArrowError",
-    "BatchedCsvReader",
+    "ColumnNotFoundError",
     "ComputeError",
+    "DuplicateError",
     "InvalidOperationError",
     "NoDataError",
-    "DuplicateError",
     "PanicException",
+    "SchemaError",
+    "SchemaFieldNotFoundError",
+    "ShapeError",
+    "StructFieldNotFoundError",
+    # core classes
+    "BatchedCsvReader",
     "DataFrame",
-    "Series",
+    "Expr",
     "LazyFrame",
+    "Series",
     # polars.datatypes
+    "Binary",
+    "Boolean",
+    "Categorical",
     "DataType",
-    "Int8",
+    "Date",
+    "Datetime",
+    "Duration",
+    "Field",
+    "Float32",
+    "Float64",
     "Int16",
     "Int32",
     "Int64",
-    "UInt8",
+    "Int8",
+    "List",
+    "Null",
+    "Object",
+    "PolarsDataType",
+    "Struct",
+    "Time",
     "UInt16",
     "UInt32",
     "UInt64",
-    "Float32",
-    "Float64",
-    "Boolean",
-    "Binary",
-    "Utf8",
-    "List",
-    "Date",
-    "Datetime",
-    "Time",
-    "Duration",
-    "Object",
-    "Categorical",
-    "Field",
-    "Struct",
-    "Null",
+    "UInt8",
     "Unknown",
-    "PolarsDataType",
+    "Utf8",
     "get_idx_type",
     # polars.io
+    "read_avro",
     "read_csv",
     "read_csv_batched",
+    "read_delta",
     "read_excel",
-    "read_parquet",
+    "read_ipc",
+    "read_ipc_schema",
     "read_json",
     "read_ndjson",
+    "read_parquet",
+    "read_parquet_schema",
     "read_sql",
-    "read_ipc",
     "scan_csv",
     "scan_delta",
-    "scan_ipc",
     "scan_ds",
-    "scan_parquet",
+    "scan_ipc",
     "scan_ndjson",
-    "read_ipc_schema",
-    "read_parquet_schema",
-    "read_avro",
-    "read_delta",
+    "scan_parquet",
     # polars.stringcache
     "StringCache",
     "toggle_string_cache",
@@ -228,79 +239,79 @@ __all__ = [
     "Config",
     # polars.internals.whenthen
     "when",
-    # polars.internals.expr
-    "Expr",
     # polars.internals.functions
     "align_frames",
     "arg_where",
     "concat",
+    "cut",
     "date_range",
+    "element",
     "get_dummies",
     "ones",
     "repeat",
-    "element",
-    "cut",
     "zeros",
     # polars.internals.lazy_functions
-    "col",
-    "count",
-    "std",
-    "var",
-    "max",
-    "min",
-    "sum",
-    "mean",
-    "avg",
-    "median",
-    "n_unique",
-    "first",
-    "last",
-    "head",
-    "tail",
-    "lit",
-    "pearson_corr",
-    "spearman_rank_corr",
-    "cov",
-    "map",
+    "all",
+    "any",
     "apply",
-    "fold",
+    "arange",
+    "arg_sort_by",
+    "argsort_by",
+    "avg",
+    "coalesce",
+    "col",
+    "collect_all",
+    "concat_list",
+    "concat_str",
+    "count",
+    "cov",
     "cumfold",
-    "reduce",
     "cumreduce",
     "cumsum",
-    "any",
-    "all",
-    "groups",
-    "quantile",
-    "arange",
-    "argsort_by",
-    "concat_str",
-    "concat_list",
-    "collect_all",
+    "date",  # name _date, see import above
+    "datetime",  # named _datetime, see import above
+    "duration",
     "exclude",
+    "first",
+    "fold",
     "format",
     "from_epoch",
-    "datetime",  # named _datetime, see import above
-    "date",  # name _date, see import above
+    "groups",
+    "head",
+    "last",
     "list",  # named to_list, see import above
+    "lit",
+    "map",
+    "max",
+    "mean",
+    "median",
+    "min",
+    "n_unique",
+    "pearson_corr",
+    "quantile",
+    "reduce",
     "select",
-    "var",
+    "spearman_rank_corr",
+    "std",
     "struct",
-    "duration",
-    "coalesce",
+    "sum",
+    "tail",
+    "var",
+    "var",
     # polars.convert
+    "from_arrow",
+    "from_dataframe",
     "from_dict",
     "from_dicts",
-    "from_records",
     "from_numpy",
-    "from_arrow",
     "from_pandas",
+    "from_records",
     # testing
     "threadpool_size",
     # version
-    "show_versions",
-    "build_info",
     "SQLContext",
+    "build_info",
+    "show_versions",
 ]
 
 __version__ = version()
