@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-import sys
+import contextlib
 import warnings
 from datetime import date, datetime, time, timedelta
 from typing import TYPE_CHECKING, Any, Callable, Iterable, Sequence, overload
@@ -11,6 +11,7 @@ from polars.datatypes import (
     Date,
     Datetime,
     Duration,
+    Int32,
     Int64,
     PolarsDataType,
     SchemaDict,
@@ -22,15 +23,15 @@ from polars.datatypes import (
 )
 from polars.dependencies import _check_for_numpy
 from polars.dependencies import numpy as np
-from polars.internals.type_aliases import EpochTimeUnit, PolarsExprType
 from polars.utils import (
     _datetime_to_pl_timestamp,
     _time_to_pl_time,
     _timedelta_to_pl_timedelta,
     deprecate_nonkeyword_arguments,
+    deprecated_alias,
 )
 
-try:
+with contextlib.suppress(ImportError):  # Module not available when building docs
     from polars.polars import arange as pyarange
     from polars.polars import arg_sort_by as py_arg_sort_by
     from polars.polars import arg_where as py_arg_where
@@ -60,23 +61,22 @@ try:
     from polars.polars import spearman_rank_corr as pyspearman_rank_corr
     from polars.polars import sum_exprs as _sum_exprs
 
-    _DOCUMENTING = False
-except ImportError:
-    _DOCUMENTING = True
-
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
 
 if TYPE_CHECKING:
+    import sys
+
     from polars.internals.type_aliases import (
+        EpochTimeUnit,
         IntoExpr,
-        PythonLiteral,
         RollingInterpolationMethod,
         TimeUnit,
     )
 
+    if sys.version_info >= (3, 8):
+        from typing import Literal
+    else:
+        from typing_extensions import Literal
+
 
 def col(
     name: str | PolarsDataType | Iterable[str] | Iterable[PolarsDataType],
@@ -220,9 +220,10 @@ def col(
             dtypes = [name]
             dtypes.extend(more_names)
             return pli.wrap_expr(_dtype_cols(dtypes))
-        raise TypeError(
-            f"Invalid input for `col`. Expected `str` or `DataType`, got {type(name)!r}"
-        )
+        else:
+            raise TypeError(
+                f"Invalid input for `col`. Expected `str` or `DataType`, got {type(name)!r}"
+            )
 
     if isinstance(name, str):
         return pli.wrap_expr(pycol(name))
@@ -1108,6 +1109,7 @@ def tail(column: str | pli.Series, n: int = 10) -> pli.Expr | pli.Series:
     return col(column).tail(n)
 
 
+@deprecate_nonkeyword_arguments(allowed_args=["value", "dtype"])
 def lit(
     value: Any, dtype: PolarsDataType | None = None, allow_object: bool = False
 ) -> pli.Expr:
@@ -1305,6 +1307,7 @@ def cumsum(
     return cumfold(lit(0).cast(UInt32), lambda a, b: a + b, column).alias("cumsum")
 
 
+@deprecate_nonkeyword_arguments(allowed_args=["a", "b", "ddof"])
 def spearman_rank_corr(
     a: str | pli.Expr, b: str | pli.Expr, ddof: int = 1, propagate_nans: bool = False
 ) -> pli.Expr:
@@ -1383,10 +1386,7 @@ def pearson_corr(a: str | pli.Expr, b: str | pli.Expr, ddof: int = 1) -> pli.Exp
     return pli.wrap_expr(pypearson_corr(a._pyexpr, b._pyexpr, ddof))
 
 
-def cov(
-    a: str | pli.Expr,
-    b: str | pli.Expr,
-) -> pli.Expr:
+def cov(a: str | pli.Expr, b: str | pli.Expr) -> pli.Expr:
     """
     Compute the covariance between two columns/ expressions.
 
@@ -1418,9 +1418,10 @@ def cov(
     return pli.wrap_expr(pycov(a._pyexpr, b._pyexpr))
 
 
+@deprecated_alias(f="function")
 def map(
     exprs: Sequence[str] | Sequence[pli.Expr],
-    f: Callable[[Sequence[pli.Series]], pli.Series],
+    function: Callable[[Sequence[pli.Series]], pli.Series],
     return_dtype: PolarsDataType | None = None,
 ) -> pli.Expr:
     """
@@ -1432,7 +1433,7 @@ def map(
     ----------
     exprs
         Input Series to f
-    f
+    function
         Function to apply over the input
     return_dtype
         dtype of the output Series
@@ -1441,17 +1442,50 @@ def map(
     -------
     Expr
 
+    Examples
+    --------
+    >>> def test_func(a, b, c):
+    ...     return a + b + c
+    ...
+    >>> df = pl.DataFrame(
+    ...     {
+    ...         "a": [1, 2, 3, 4],
+    ...         "b": [4, 5, 6, 7],
+    ...     }
+    ... )
+    >>>
+    >>> df.with_columns(
+    ...     (
+    ...         pl.struct(["a", "b"]).map(
+    ...             lambda x: test_func(x.struct.field("a"), x.struct.field("b"), 1)
+    ...         )
+    ...     ).alias("a+b+c")
+    ... )
+    shape: (4, 3)
+    ┌─────┬─────┬───────┐
+    │ a   ┆ b   ┆ a+b+c │
+    │ --- ┆ --- ┆ ---   │
+    │ i64 ┆ i64 ┆ i64   │
+    ╞═════╪═════╪═══════╡
+    │ 1   ┆ 4   ┆ 6     │
+    │ 2   ┆ 5   ┆ 8     │
+    │ 3   ┆ 6   ┆ 10    │
+    │ 4   ┆ 7   ┆ 12    │
+    └─────┴─────┴───────┘
     """
     exprs = pli.selection_to_pyexpr_list(exprs)
     return pli.wrap_expr(
-        _map_mul(exprs, f, return_dtype, apply_groups=False, returns_scalar=False)
+        _map_mul(
+            exprs, function, return_dtype, apply_groups=False, returns_scalar=False
+        )
     )
 
 
-@deprecate_nonkeyword_arguments(allowed_args=["exprs", "f", "return_dtype"])
+@deprecated_alias(f="function")
+@deprecate_nonkeyword_arguments(allowed_args=["exprs", "function", "return_dtype"])
 def apply(
     exprs: Sequence[str | pli.Expr],
-    f: Callable[[Sequence[pli.Series]], pli.Series | Any],
+    function: Callable[[Sequence[pli.Series]], pli.Series | Any],
     return_dtype: PolarsDataType | None = None,
     returns_scalar: bool = True,
 ) -> pli.Expr:
@@ -1470,7 +1504,7 @@ def apply(
     ----------
     exprs
         Input Series to f
-    f
+    function
         Function to apply over the input
     return_dtype
         dtype of the output Series
@@ -1481,18 +1515,58 @@ def apply(
     -------
     Expr
 
+    Examples
+    --------
+    >>> df = pl.DataFrame(
+    ...     {
+    ...         "a": [7, 2, 3, 4],
+    ...         "b": [2, 5, 6, 7],
+    ...     }
+    ... )
+    >>> df
+    shape: (4, 2)
+    ┌─────┬─────┐
+    │ a   ┆ b   │
+    │ --- ┆ --- │
+    │ i64 ┆ i64 │
+    ╞═════╪═════╡
+    │ 7   ┆ 2   │
+    │ 2   ┆ 5   │
+    │ 3   ┆ 6   │
+    │ 4   ┆ 7   │
+    └─────┴─────┘
+
+    Calculate product of ``a``.
+
+    >>> df.with_columns(pl.col("a").apply(lambda x: x * x).alias("product_a"))
+    shape: (4, 3)
+    ┌─────┬─────┬───────────┐
+    │ a   ┆ b   ┆ product_a │
+    │ --- ┆ --- ┆ ---       │
+    │ i64 ┆ i64 ┆ i64       │
+    ╞═════╪═════╪═══════════╡
+    │ 7   ┆ 2   ┆ 49        │
+    │ 2   ┆ 5   ┆ 4         │
+    │ 3   ┆ 6   ┆ 9         │
+    │ 4   ┆ 7   ┆ 16        │
+    └─────┴─────┴───────────┘
     """
     exprs = pli.selection_to_pyexpr_list(exprs)
     return pli.wrap_expr(
         _map_mul(
-            exprs, f, return_dtype, apply_groups=True, returns_scalar=returns_scalar
+            exprs,
+            function,
+            return_dtype,
+            apply_groups=True,
+            returns_scalar=returns_scalar,
         )
     )
 
 
+@deprecated_alias(f="function")
 def fold(
     acc: IntoExpr,
-    f: Callable[[pli.Series, pli.Series], pli.Series],
+    function: Callable[[pli.Series, pli.Series], pli.Series],
     exprs: Sequence[pli.Expr | str] | pli.Expr,
 ) -> pli.Expr:
     """
@@ -1503,7 +1577,7 @@ def fold(
     acc
         Accumulator Expression. This is the value that will be initialized when the fold
         starts. For a sum this could for instance be lit(0).
-    f
+    function
         Function to apply over the accumulator and the value.
         Fn(acc, value) -> new_value
     exprs
@@ -1514,6 +1588,80 @@ def fold(
     If you simply want the first encountered expression as accumulator,
     consider using ``reduce``.
 
+    Examples
+    --------
+    >>> df = pl.DataFrame(
+    ...     {
+    ...         "a": [1, 2, 3],
+    ...         "b": [3, 4, 5],
+    ...         "c": [5, 6, 7],
+    ...     }
+    ... )
+    >>> df
+    shape: (3, 3)
+    ┌─────┬─────┬─────┐
+    │ a   ┆ b   ┆ c   │
+    │ --- ┆ --- ┆ --- │
+    │ i64 ┆ i64 ┆ i64 │
+    ╞═════╪═════╪═════╡
+    │ 1   ┆ 3   ┆ 5   │
+    │ 2   ┆ 4   ┆ 6   │
+    │ 3   ┆ 5   ┆ 7   │
+    └─────┴─────┴─────┘
+
+    Horizontally sum over all columns and add 1.
+
+    >>> df.select(
+    ...     pl.fold(acc=pl.lit(1), f=lambda acc, x: acc + x, exprs=pl.col("*")).alias(
+    ...         "sum"
+    ...     ),
+    ... )
+    shape: (3, 1)
+    ┌─────┐
+    │ sum │
+    │ --- │
+    │ i64 │
+    ╞═════╡
+    │ 10  │
+    │ 13  │
+    │ 16  │
+    └─────┘
+
+    You can also apply a condition/predicate on all columns:
+
+    >>> df = pl.DataFrame(
+    ...     {
+    ...         "a": [1, 2, 3],
+    ...         "b": [0, 1, 2],
+    ...     }
+    ... )
+    >>> df
+    shape: (3, 2)
+    ┌─────┬─────┐
+    │ a   ┆ b   │
+    │ --- ┆ --- │
+    │ i64 ┆ i64 │
+    ╞═════╪═════╡
+    │ 1   ┆ 0   │
+    │ 2   ┆ 1   │
+    │ 3   ┆ 2   │
+    └─────┴─────┘
+
+    >>> df.filter(
+    ...     pl.fold(
+    ...         acc=pl.lit(True),
+    ...         f=lambda acc, x: acc & x,
+    ...         exprs=pl.col("*") > 1,
+    ...     )
+    ... )
+    shape: (1, 2)
+    ┌─────┬─────┐
+    │ a   ┆ b   │
+    │ --- ┆ --- │
+    │ i64 ┆ i64 │
+    ╞═════╪═════╡
+    │ 3   ┆ 2   │
+    └─────┴─────┘
     """
     # in case of pl.col("*")
     acc = pli.expr_to_lit_or_expr(acc, str_to_lit=True)
@@ -1521,11 +1669,12 @@ def fold(
         exprs = [exprs]
 
     exprs = pli.selection_to_pyexpr_list(exprs)
-    return pli.wrap_expr(pyfold(acc._pyexpr, f, exprs))
+    return pli.wrap_expr(pyfold(acc._pyexpr, function, exprs))
 
 
+@deprecated_alias(f="function")
 def reduce(
-    f: Callable[[pli.Series, pli.Series], pli.Series],
+    function: Callable[[pli.Series, pli.Series], pli.Series],
     exprs: Sequence[pli.Expr | str] | pli.Expr,
 ) -> pli.Expr:
     """
@@ -1533,7 +1682,7 @@ def reduce(
 
     Parameters
     ----------
-    f
+    function
         Function to apply over the accumulator and the value.
         Fn(acc, value) -> new_value
     exprs
@@ -1543,19 +1692,56 @@ def reduce(
     -----
     See ``fold`` for the version with an explicit accumulator.
 
+    Examples
+    --------
+    >>> df = pl.DataFrame(
+    ...     {
+    ...         "a": [1, 2, 3],
+    ...         "b": [0, 1, 2],
+    ...     }
+    ... )
+    >>> df
+    shape: (3, 2)
+    ┌─────┬─────┐
+    │ a   ┆ b   │
+    │ --- ┆ --- │
+    │ i64 ┆ i64 │
+    ╞═════╪═════╡
+    │ 1   ┆ 0   │
+    │ 2   ┆ 1   │
+    │ 3   ┆ 2   │
+    └─────┴─────┘
+
+    Horizontally sum over all columns.
+
+    >>> df.select(
+    ...     pl.reduce(f=lambda acc, x: acc + x, exprs=pl.col("*")).alias("sum"),
+    ... )
+    shape: (3, 1)
+    ┌─────┐
+    │ sum │
+    │ --- │
+    │ i64 │
+    ╞═════╡
+    │ 1   │
+    │ 3   │
+    │ 5   │
+    └─────┘
+
     """
     # in case of pl.col("*")
     if isinstance(exprs, pli.Expr):
         exprs = [exprs]
 
     exprs = pli.selection_to_pyexpr_list(exprs)
-    return pli.wrap_expr(pyreduce(f, exprs))
+    return pli.wrap_expr(pyreduce(function, exprs))
 
 
+@deprecated_alias(f="function")
 @deprecate_nonkeyword_arguments()
 def cumfold(
     acc: IntoExpr,
-    f: Callable[[pli.Series, pli.Series], pli.Series],
+    function: Callable[[pli.Series, pli.Series], pli.Series],
     exprs: Sequence[pli.Expr | str] | pli.Expr,
     include_init: bool = False,
 ) -> pli.Expr:
@@ -1569,7 +1755,7 @@ def cumfold(
     acc
         Accumulator Expression. This is the value that will be initialized when the fold
         starts. For a sum this could for instance be lit(0).
-    f
+    function
         Function to apply over the accumulator and the value.
         Fn(acc, value) -> new_value
     exprs
@@ -1582,6 +1768,43 @@ def cumfold(
     If you simply want the first encountered expression as accumulator,
     consider using ``cumreduce``.
 
+    Examples
+    --------
+    >>> df = pl.DataFrame(
+    ...     {
+    ...         "a": [1, 2, 3],
+    ...         "b": [3, 4, 5],
+    ...         "c": [5, 6, 7],
+    ...     }
+    ... )
+    >>> df
+    shape: (3, 3)
+    ┌─────┬─────┬─────┐
+    │ a   ┆ b   ┆ c   │
+    │ --- ┆ --- ┆ --- │
+    │ i64 ┆ i64 ┆ i64 │
+    ╞═════╪═════╪═════╡
+    │ 1   ┆ 3   ┆ 5   │
+    │ 2   ┆ 4   ┆ 6   │
+    │ 3   ┆ 5   ┆ 7   │
+    └─────┴─────┴─────┘
+
+    >>> df.select(
+    ...     pl.cumfold(
+    ...         acc=pl.lit(1), f=lambda acc, x: acc + x, exprs=pl.col("*")
+    ...     ).alias("cumfold"),
+    ... )
+    shape: (3, 1)
+    ┌───────────┐
+    │ cumfold   │
+    │ ---       │
+    │ struct[3] │
+    ╞═══════════╡
+    │ {2,5,10}  │
+    │ {3,7,13}  │
+    │ {4,9,16}  │
+    └───────────┘
+
     """  # noqa: W505
     # in case of pl.col("*")
     acc = pli.expr_to_lit_or_expr(acc, str_to_lit=True)
@@ -1589,11 +1812,12 @@ def cumfold(
         exprs = [exprs]
 
     exprs = pli.selection_to_pyexpr_list(exprs)
-    return pli.wrap_expr(pycumfold(acc._pyexpr, f, exprs, include_init))
+    return pli.wrap_expr(pycumfold(acc._pyexpr, function, exprs, include_init))
 
 
+@deprecated_alias(f="function")
 def cumreduce(
-    f: Callable[[pli.Series, pli.Series], pli.Series],
+    function: Callable[[pli.Series, pli.Series], pli.Series],
     exprs: Sequence[pli.Expr | str] | pli.Expr,
 ) -> pli.Expr:
     """
@@ -1603,23 +1827,96 @@ def cumreduce(
 
     Parameters
     ----------
-    f
+    function
         Function to apply over the accumulator and the value.
         Fn(acc, value) -> new_value
     exprs
         Expressions to aggregate over. May also be a wildcard expression.
 
+    Examples
+    --------
+    >>> df = pl.DataFrame(
+    ...     {
+    ...         "a": [1, 2, 3],
+    ...         "b": [3, 4, 5],
+    ...         "c": [5, 6, 7],
+    ...     }
+    ... )
+    >>> df
+    shape: (3, 3)
+    ┌─────┬─────┬─────┐
+    │ a   ┆ b   ┆ c   │
+    │ --- ┆ --- ┆ --- │
+    │ i64 ┆ i64 ┆ i64 │
+    ╞═════╪═════╪═════╡
+    │ 1   ┆ 3   ┆ 5   │
+    │ 2   ┆ 4   ┆ 6   │
+    │ 3   ┆ 5   ┆ 7   │
+    └─────┴─────┴─────┘
+
+    >>> df.select(
+    ...     pl.cumreduce(f=lambda acc, x: acc + x, exprs=pl.col("*")).alias(
+    ...         "cumreduce"
+    ...     ),
+    ... )
+    shape: (3, 1)
+    ┌───────────┐
+    │ cumreduce │
+    │ ---       │
+    │ struct[3] │
+    ╞═══════════╡
+    │ {1,4,9}   │
+    │ {2,6,12}  │
+    │ {3,8,15}  │
+    └───────────┘
     """  # noqa: W505
     # in case of pl.col("*")
     if isinstance(exprs, pli.Expr):
         exprs = [exprs]
 
     exprs = pli.selection_to_pyexpr_list(exprs)
-    return pli.wrap_expr(pycumreduce(f, exprs))
+    return pli.wrap_expr(pycumreduce(function, exprs))
 
 
 def any(name: str | Sequence[str] | Sequence[pli.Expr] | pli.Expr) -> pli.Expr:
-    """Evaluate columnwise or elementwise with a bitwise OR operation."""
+    """
+    Evaluate columnwise or elementwise with a bitwise OR operation.
+
+    Examples
+    --------
+    >>> df = pl.DataFrame(
+    ...     {
+    ...         "a": [True, False, True],
+    ...         "b": [False, False, False],
+    ...         "c": [False, True, False],
+    ...     }
+    ... )
+    >>> df
+    shape: (3, 3)
+    ┌───────┬───────┬───────┐
+    │ a     ┆ b     ┆ c     │
+    │ ---   ┆ ---   ┆ ---   │
+    │ bool  ┆ bool  ┆ bool  │
+    ╞═══════╪═══════╪═══════╡
+    │ true  ┆ false ┆ false │
+    │ false ┆ false ┆ true  │
+    │ true  ┆ false ┆ false │
+    └───────┴───────┴───────┘
+
+    Compares the values (in binary format) and return true if any value in the column
+    is true.
+
+    >>> df.select(pl.any("*"))
+    shape: (1, 3)
+    ┌──────┬───────┬──────┐
+    │ a    ┆ b     ┆ c    │
+    │ ---  ┆ ---   ┆ ---  │
+    │ bool ┆ bool  ┆ bool │
+    ╞══════╪═══════╪══════╡
+    │ true ┆ false ┆ true │
+    └──────┴───────┴──────┘
+
+    """
     if isinstance(name, str):
         return col(name).any()
     else:
@@ -1629,34 +1926,27 @@ def any(name: str | Sequence[str] | Sequence[pli.Expr] | pli.Expr) -> pli.Expr:
 
 
 def exclude(
-    columns: (
-        str
-        | PolarsDataType
-        | Sequence[str]
-        | Sequence[PolarsDataType]
-        | set[PolarsDataType]
-        | frozenset[PolarsDataType]
-    ),
+    columns: str | PolarsDataType | Iterable[str] | Iterable[PolarsDataType],
+    *more_columns: str | PolarsDataType,
 ) -> pli.Expr:
     """
-    Exclude certain columns from a wildcard/regex selection.
+    Represent all columns except for the given columns.
 
-    Syntactic sugar for:
-
-    >>> pl.all().exclude(columns)  # doctest: +SKIP
+    Syntactic sugar for ``pl.all().exclude(columns)``.
 
     Parameters
     ----------
     columns
-        Column(s) to exclude from selection
-        This can be:
-
-        - a column name, or multiple column names
-        - a regular expression starting with `^` and ending with `$`
-        - a dtype or multiple dtypes
+        The name or datatype of the column(s) to exclude. Accepts regular expression
+        input. Regular expressions should start with ``^`` and end with ``$``.
+    *more_columns
+        Additional names or datatypes of columns to exclude, specified as positional
+        arguments.
 
     Examples
     --------
+    Exclude by column name(s):
+
     >>> df = pl.DataFrame(
     ...     {
     ...         "aa": [1, 2, 3],
@@ -1664,20 +1954,6 @@ def exclude(
     ...         "cc": [None, 2.5, 1.5],
     ...     }
     ... )
-    >>> df
-    shape: (3, 3)
-    ┌─────┬──────┬──────┐
-    │ aa  ┆ ba   ┆ cc   │
-    │ --- ┆ ---  ┆ ---  │
-    │ i64 ┆ str  ┆ f64  │
-    ╞═════╪══════╪══════╡
-    │ 1   ┆ a    ┆ null │
-    │ 2   ┆ b    ┆ 2.5  │
-    │ 3   ┆ null ┆ 1.5  │
-    └─────┴──────┴──────┘
-
-    Exclude by column name(s):
-
     >>> df.select(pl.exclude("ba"))
     shape: (3, 2)
     ┌─────┬──────┐
@@ -1719,7 +1995,7 @@ def exclude(
     └──────┘
 
     """
-    return col("*").exclude(columns)
+    return col("*").exclude(columns, *more_columns)
 
 
 def all(name: str | Sequence[pli.Expr] | pli.Expr | None = None) -> pli.Expr:
@@ -1872,10 +2148,11 @@ def arange(
         )
 
 
+@deprecated_alias(reverse="descending")
 @deprecate_nonkeyword_arguments()
 def arg_sort_by(
     exprs: pli.Expr | str | Sequence[pli.Expr | str],
-    reverse: Sequence[bool] | bool = False,
+    descending: Sequence[bool] | bool = False,
 ) -> pli.Expr:
     """
     Find the indexes that would sort the columns.
@@ -1888,21 +2165,22 @@ def arg_sort_by(
     ----------
     exprs
         Columns use to determine the ordering.
-    reverse
-        Default is ascending.
+    descending
+        Sort descending; default is ascending.
 
     """
     if isinstance(exprs, str) or not isinstance(exprs, Sequence):
         exprs = [exprs]
-    if isinstance(reverse, bool):
-        reverse = [reverse] * len(exprs)
+    if isinstance(descending, bool):
+        descending = [descending] * len(exprs)
     exprs = pli.selection_to_pyexpr_list(exprs)
-    return pli.wrap_expr(py_arg_sort_by(exprs, reverse))
+    return pli.wrap_expr(py_arg_sort_by(exprs, descending))
 
 
+@deprecated_alias(reverse="descending")
 def argsort_by(
     exprs: pli.Expr | str | Sequence[pli.Expr | str],
-    reverse: Sequence[bool] | bool = False,
+    descending: Sequence[bool] | bool = False,
 ) -> pli.Expr:
     """
     Find the indexes that would sort the columns.
@@ -1918,8 +2196,8 @@ def argsort_by(
     ----------
     exprs
         Columns use to determine the ordering.
-    reverse
-        Default is ascending.
+    descending
+        Sort in descending order; default is ascending.
 
     """
     warnings.warn(
@@ -1927,7 +2205,7 @@ def argsort_by(
         DeprecationWarning,
         stacklevel=2,
     )
-    return pli.arg_sort_by(exprs, reverse)
+    return pli.arg_sort_by(exprs, descending)
 
 
 def duration(
@@ -2248,6 +2526,7 @@ def concat_list(exprs: Sequence[str | pli.Expr | pli.Series] | pli.Expr) -> pli.
     return pli.wrap_expr(_concat_lst(exprs))
 
 
+@deprecate_nonkeyword_arguments()
 def collect_all(
     lazy_frames: Sequence[pli.LazyFrame],
     type_coercion: bool = True,
@@ -2319,16 +2598,9 @@ def collect_all(
 
 
 def select(
-    exprs: (
-        str
-        | PolarsExprType
-        | PythonLiteral
-        | pli.Series
-        | Iterable[str | PolarsExprType | PythonLiteral | pli.Series | None]
-        | None
-    ) = None,
-    *more_exprs: str | PolarsExprType | PythonLiteral | pli.Series | None,
-    **named_exprs: str | PolarsExprType | PythonLiteral | pli.Series | None,
+    exprs: IntoExpr | Iterable[IntoExpr] | None = None,
+    *more_exprs: IntoExpr,
+    **named_exprs: IntoExpr,
 ) -> pli.DataFrame:
     """
     Run polars expressions without a context.
@@ -2520,6 +2792,12 @@ def repeat(
         if name is None:
             name = ""
         dtype = py_type_to_dtype(type(value))
+        if (
+            dtype == Int64
+            and isinstance(value, int)
+            and -(2**31) <= value <= 2**31 - 1
+        ):
+            dtype = Int32
         s = pli.Series._repeat(name, value, n, dtype)  # type: ignore[arg-type]
         return s
     else:
@@ -2637,7 +2915,8 @@ def coalesce(exprs: IntoExpr | Iterable[IntoExpr], *more_exprs: IntoExpr) -> pli
 
     """
     exprs = pli.selection_to_pyexpr_list(exprs)
-    exprs.extend(pli.selection_to_pyexpr_list(more_exprs))
+    if more_exprs:
+        exprs.extend(pli.selection_to_pyexpr_list(more_exprs))
     return pli.wrap_expr(_coalesce_exprs(exprs))
 
 
