@@ -1,6 +1,5 @@
 from __future__ import annotations
 
-from datetime import date, datetime, time, timedelta
 from typing import TYPE_CHECKING
 
 import polars.internals as pli
@@ -8,6 +7,8 @@ from polars.internals.series.utils import expr_dispatch
 from polars.utils import _to_python_datetime, deprecated_alias, redirect
 
 if TYPE_CHECKING:
+    from datetime import date, datetime, time, timedelta
+
     from polars.internals.type_aliases import EpochTimeUnit, TimeUnit
     from polars.polars import PySeries
 
@@ -32,7 +33,7 @@ class DateTimeNameSpace:
         s = pli.wrap_s(self._s)
         return s[item]
 
-    def min(self) -> date | datetime | timedelta:
+    def min(self) -> date | datetime | timedelta | None:
         """
         Return minimum as python DateTime.
 
@@ -52,10 +53,9 @@ class DateTimeNameSpace:
         datetime.datetime(2001, 1, 1, 0, 0)
 
         """
-        # we can ignore types because we are certain we get a logical type
         return pli.wrap_s(self._s).min()  # type: ignore[return-value]
 
-    def max(self) -> date | datetime | timedelta:
+    def max(self) -> date | datetime | timedelta | None:
         """
         Return maximum as python DateTime.
 
