@@ -3,11 +3,10 @@ from __future__ import annotations
 from typing import TYPE_CHECKING
 
 import polars.internals as pli
-from polars.datatypes import PolarsTemporalType
 from polars.internals.series.utils import expr_dispatch
-from polars.utils import deprecated_alias
 
 if TYPE_CHECKING:
+    from polars.datatypes import PolarsDataType, PolarsTemporalType
     from polars.internals.type_aliases import TransferEncoding
     from polars.polars import PySeries
 
@@ -29,6 +28,7 @@ class StringNameSpace:
         exact: bool = True,
         cache: bool = True,
         tz_aware: bool = False,
+        utc: bool = False,
     ) -> pli.Series:
         """
         Parse a Series of dtype Utf8 to a Date/Datetime Series.
@@ -42,9 +42,6 @@ class StringNameSpace:
             `chrono strftime documentation
             <https://docs.rs/chrono/latest/chrono/format/strftime/index.html>`_
             for specification. Example: ``"%y-%m-%d"``.
-            Note that the ``Z`` suffix for "Zulu time" in ISO8601 formats is not (yet!)
-            fully supported: you should first try ``"%+"`` and if that fails, insert a
-            ``Z`` in your ``fmt`` string and then use ``dt.with_time_zone``.
         strict
             Raise an error if any conversion fails.
         exact
@@ -55,6 +52,9 @@ class StringNameSpace:
         tz_aware
             Parse timezone aware datetimes. This may be automatically toggled by the
             'fmt' given.
+        utc
+            Parse timezone aware datetimes as UTC. This may be useful if you have data
+            with mixed offsets.
 
         Returns
         -------
@@ -62,6 +62,17 @@ class StringNameSpace:
 
         Examples
         --------
+        Dealing with a consistent format:
+
+        >>> ts = ["2020-01-01 01:00Z", "2020-01-01 02:00Z"]
+        >>> pl.Series(ts).str.strptime(pl.Datetime, "%Y-%m-%d %H:%M%#z")
+        shape: (2,)
+        Series: '' [datetime[μs, +00:00]]
+        [
+                2020-01-01 01:00:00 +00:00
+                2020-01-01 02:00:00 +00:00
+        ]
+
         Dealing with different formats.
 
         >>> s = pl.Series(
@@ -175,7 +186,7 @@ class StringNameSpace:
         """
 
     def contains(
-        self, pattern: str, literal: bool = False, strict: bool = True
+        self, pattern: str | pli.Expr, literal: bool = False, strict: bool = True
     ) -> pli.Series:
         """
         Check if strings in Series contain a substring that matches a regex.
@@ -218,7 +229,7 @@ class StringNameSpace:
 
         """
 
-    def ends_with(self, sub: str) -> pli.Series:
+    def ends_with(self, sub: str | pli.Expr) -> pli.Series:
         """
         Check if string values end with a substring.
 
@@ -246,7 +257,7 @@ class StringNameSpace:
 
         """
 
-    def starts_with(self, sub: str) -> pli.Series:
+    def starts_with(self, sub: str | pli.Expr) -> pli.Series:
         """
         Check if string values start with a substring.
 
@@ -315,6 +326,37 @@ class StringNameSpace:
 
         """
 
+    def json_extract(self, dtype: PolarsDataType | None = None) -> pli.Series:
+        """
+        Parse string values as JSON.
+
+        Throw errors if encounter invalid JSON strings.
+
+        Parameters
+        ----------
+        dtype
+            The dtype to cast the extracted value to. If None, the dtype will be
+            inferred from the JSON value.
+
+        Examples
+        --------
+        >>> s = pl.Series("json", ['{"a":1, "b": true}', None, '{"a":2, "b": false}'])
+        >>> s.str.json_extract()
+        shape: (3,)
+        Series: 'json' [struct[2]]
+        [
+                {1,true}
+                {null,null}
+                {2,false}
+        ]
+
+        See Also
+        --------
+        json_path_match : Extract the first match of json string with provided JSONPath
+            expression.
+
+        """
+
     def json_path_match(self, json_path: str) -> pli.Series:
         """
         Extract the first match of json string with provided JSONPath expression.
@@ -836,7 +878,6 @@ class StringNameSpace:
     def to_uppercase(self) -> pli.Series:
         """Modify the strings to their uppercase equivalent."""
 
-    @deprecated_alias(start="offset")
     def slice(self, offset: int, length: int | None = None) -> pli.Series:
         """
         Create subslices of the string values of a Utf8 Series.
@@ -880,10 +921,6 @@ class StringNameSpace:
         ]
 
         """
-        s = pli.wrap_s(self._s)
-        return (
-            s.to_frame().select(pli.col(s.name).str.slice(offset, length)).to_series()
-        )
 
     def explode(self) -> pli.Series:
         """
@@ -909,3 +946,43 @@ class StringNameSpace:
         ]
 
         """
+
+    def parse_int(self, radix: int = 2) -> pli.Series:
+        r"""
+        Parse integers with base radix from strings.
+
+        By default base 2.
+
+        Parameters
+        ----------
+        radix
+            Positive integer which is the base of the string we are parsing.
+            Default: 2
+
+        Returns
+        -------
+        Column of parsed integers in i32 format
+
+        Examples
+        --------
+        >>> s = pl.Series("bin", ["110", "101", "010"])
+        >>> s.str.parse_int(2)
+        shape: (3,)
+        Series: 'bin' [i32]
+        [
+                6
+                5
+                2
+        ]
+
+        >>> s = pl.Series("hex", ["fa1e", "ff00", "cafe"])
+        >>> s.str.parse_int(16)
+        shape: (3,)
+        Series: 'hex' [i32]
+        [
+                64030
+                65280
+                51966
+        ]
+
+        """
