@@ -286,7 +286,7 @@ impl PyLazyFrame {
     #[staticmethod]
     #[allow(clippy::too_many_arguments)]
     #[pyo3(signature = (path, n_rows, cache, parallel, rechunk, row_count,
-        low_memory, cloud_options)
+        low_memory, cloud_options, use_statistics)
     )]
     pub fn new_from_parquet(
         path: String,
@@ -297,6 +297,7 @@ impl PyLazyFrame {
         row_count: Option<(String, IdxSize)>,
         low_memory: bool,
         cloud_options: Option<PyObject>,
+        use_statistics: bool,
     ) -> PyResult<Self> {
         let cloud_options = cloud_options
             .map(|po| extract_cloud_options(&path, po))
@@ -310,6 +311,7 @@ impl PyLazyFrame {
             row_count,
             low_memory,
             cloud_options,
+            use_statistics,
         };
         let lf = LazyFrame::scan_parquet(path, args).map_err(PyPolarsErr::from)?;
         Ok(lf.into())
@@ -402,12 +404,12 @@ impl PyLazyFrame {
         ldf.into()
     }
 
-    pub fn sort(&self, by_column: &str, reverse: bool, nulls_last: bool) -> PyLazyFrame {
+    pub fn sort(&self, by_column: &str, descending: bool, nulls_last: bool) -> PyLazyFrame {
         let ldf = self.ldf.clone();
         ldf.sort(
             by_column,
             SortOptions {
-                descending: reverse,
+                descending,
                 nulls_last,
                 multithreaded: true,
             },
@@ -418,12 +420,12 @@ impl PyLazyFrame {
     pub fn sort_by_exprs(
         &self,
         by: Vec<PyExpr>,
-        reverse: Vec<bool>,
+        descending: Vec<bool>,
         nulls_last: bool,
     ) -> PyLazyFrame {
         let ldf = self.ldf.clone();
         let exprs = py_exprs_to_exprs(by);
-        ldf.sort_by_exprs(exprs, reverse, nulls_last).into()
+        ldf.sort_by_exprs(exprs, descending, nulls_last).into()
     }
 
     pub fn cache(&self) -> PyLazyFrame {
@@ -904,9 +906,9 @@ impl PyLazyFrame {
         ldf.map(function, opt, udf_schema, None).into()
     }
 
-    pub fn drop_columns(&self, cols: Vec<String>) -> Self {
+    pub fn drop(&self, columns: Vec<String>) -> Self {
         let ldf = self.ldf.clone();
-        ldf.drop_columns(cols).into()
+        ldf.drop_columns(columns).into()
     }
 
     pub fn clone(&self) -> PyLazyFrame {
