@@ -285,6 +285,12 @@ impl PySeries {
                 ca.rename(name);
                 ca.into_inner().into_series().into()
             }
+            DataType::Int32 => {
+                let val = val.extract::<i32>().unwrap();
+                let mut ca: NoNull<Int32Chunked> = (0..n).map(|_| val).collect_trusted();
+                ca.rename(name);
+                ca.into_inner().into_series().into()
+            }
             DataType::Float64 => {
                 let val = val.extract::<f64>().unwrap();
                 let mut ca: NoNull<Float64Chunked> = (0..n).map(|_| val).collect_trusted();
@@ -297,6 +303,10 @@ impl PySeries {
                 ca.rename(name);
                 ca.into_series().into()
             }
+            DataType::Null => {
+                let s = Series::new_null(name, n);
+                PySeries::new(s)
+            }
             dt => {
                 panic!("cannot create repeat with dtype: {dt:?}");
             }
@@ -831,6 +841,7 @@ impl PySeries {
                     | DataType::Date
                     | DataType::Duration(_)
                     | DataType::Categorical(_)
+                    | DataType::Binary
                     | DataType::Time
             ) || !skip_nulls
             {
