@@ -65,14 +65,6 @@ def test_string_numeric_comp_err() -> None:
         pl.DataFrame({"a": [1.1, 21, 31, 21, 51, 61, 71, 81]}).select(pl.col("a") < "9")
 
 
-def test_panic_exception() -> None:
-    with pytest.raises(
-        pl.PanicException,
-        match=r"""this operation is not implemented/valid for this dtype: .*""",
-    ):
-        pl.struct(pl.Series("a", [1, 2, 3]), eager=True).sort()
-
-
 @typing.no_type_check
 def test_join_lazy_on_df() -> None:
     df_left = pl.DataFrame(
@@ -293,7 +285,7 @@ def test_invalid_sort_by() -> None:
         pl.ComputeError,
         match="The sortby operation produced a different length than the Series that has to be sorted.",
     ):
-        df.select(pl.col("a").filter(pl.col("b") == "M").sort_by("c", reverse=True))
+        df.select(pl.col("a").filter(pl.col("b") == "M").sort_by("c", descending=True))
 
 
 def test_epoch_time_type() -> None:
